@@ -20,30 +20,13 @@
 
 #include <string.h>
 
-#include "producer_libdv.h"
-#include "consumer_libdv.h"
+#include <framework/mlt.h>
 
-void *mlt_create_producer( char *id, void *arg )
+extern mlt_consumer consumer_libdv_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
+extern mlt_producer producer_libdv_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
+
+MLT_REPOSITORY
 {
-	if ( !strcmp( id, "libdv" ) )
-		return producer_libdv_init( arg );
-	return NULL;
+	MLT_REGISTER( consumer_type, "libdv", consumer_libdv_init );
+	MLT_REGISTER( producer_type, "libdv", producer_libdv_init );
 }
-
-void *mlt_create_filter( char *id, void *arg )
-{
-	return NULL;
-}
-
-void *mlt_create_transition( char *id, void *arg )
-{
-	return NULL;
-}
-
-void *mlt_create_consumer( char *id, void *arg )
-{
-	if ( !strcmp( id, "libdv" ) )
-		return consumer_libdv_init( arg );
-	return NULL;
-}
-
